<template>
  <a-card
    title="日常保养标准"
    :bordered='false'
  >
    <div class='table-page-search-wrapper'>
      <a-form
        layout='inline'
        @keyup.enter.native='searchQuery'
      >
        <a-row :gutter='24'>
          <a-col
            :xl='6'
            :lg='7'
            :md='8'
            :sm='24'
          >
            <a-form-item label='标准编码'>
              <a-input
                placeholder='请输入标准编码'
                v-model='queryParam.num'
              ></a-input>
            </a-form-item>
          </a-col>
          <a-col
            :xl='6'
            :lg='7'
            :md='8'
            :sm='24'
          >
            <a-form-item label='设备名称'>
              <a-input
                placeholder='请输入设备名称'
                v-model='queryParam.name'
              ></a-input>
            </a-form-item>
          </a-col>
          <a-col
            :md="10"
            :sm="8"
          >
            <a-form-item label="版本状态">
              <a-radio-group
                v-model="queryParam.versionStatus"
                @change="onChange"
                default-value="2"
              >
                <a-radio-button value="1">
                  未生效
                </a-radio-button>
                <a-radio-button value="2">
                  已生效
                </a-radio-button>
                <a-radio-button value="3">
                  已失效
                </a-radio-button>
              </a-radio-group>
            </a-form-item>
          </a-col>
          <!-- <a-col
            :xl='6'
            :lg='7'
            :md='8'
            :sm='24'
          >
            <span
              style='float: left;overflow: hidden;'
              class='table-page-search-submitButtons'
            >
              <a-button
                type='primary'
                @click='searchQuery'
                icon='search'
              >查询</a-button>
              <a-button
                type='primary'
                @click='searchReset'
                icon='reload'
                style='margin-left: 8px'
              >重置</a-button>
            </span>
          </a-col> -->
        </a-row>
      </a-form>
    </div>

    <div class="table-operator">
      <a-button
        @click='handleAdd'
        type='primary'
        icon='plus'
        v-has="'dailyMaintenanceStandard:add'"
      >新增</a-button>
      <a-button
        type='primary'
        @click='searchQuery'
        icon='search'
      >查询</a-button>
      <a-button
        type='primary'
        @click='searchReset'
        icon='reload'
        style='margin-left: 8px'
      >重置</a-button>
    </div>

    <!-- table区域-begin -->
    <div>
      <div
        class='ant-alert ant-alert-info'
        style='margin-bottom: 16px;'
      >
        <i class='anticon anticon-info-circle ant-alert-icon'></i> 已选择 <a style='font-weight: 600'>{{ selectedRowKeys.length }}</a>项
        <a
          style='margin-left: 24px'
          @click='onClearSelected'
        >清空</a>
      </div>

      <a-table
        ref='table'
        size='middle'
        bordered
        rowKey='id'
        :scroll="{ x: 'calc(1400px + 50%)', y: 900 }"
        :columns='columns'
        :dataSource='dataSource'
        :pagination='ipagination'
        :loading='loading'
        :rowSelection='{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}'
        :customRow='clickThenSelect'
        @change='handleTableChange'
      >

        <!-- <span
          slot='action'
          slot-scope='text, record'
        >
          <a @click='handleEdit(record)'>编辑</a>

          <a-divider type='vertical' />
          <a-dropdown>
            <a class='ant-dropdown-link'>更多 <a-icon type='down' /></a>
            <a-menu slot='overlay'>
              <a-menu-item>
                <a-popconfirm
                  title='确定删除吗?'
                  @confirm='() => handleDelete(record.id)'
                >
                  <a>删除</a>
                </a-popconfirm>
              </a-menu-item>
            </a-menu>
          </a-dropdown>
        </span> -->

        <span
          slot="action"
          slot-scope="text, record"
        >
          <a
            v-if="record.versionStatus == '2'"
            @click="handleRevise(record)"
            v-has="'dailyMaintenanceStandard:revise'"
          >升版</a>
          <a
            v-if="record.versionStatus == '1'"
            @click="handleTakeEffect(record)"
            v-has="'dailyMaintenanceStandard:takeEffect'"
          >生效</a>
          <a-divider type="vertical" />
          <a
            v-if="record.versionStatus == '1'"
            @click="handleEdit(record)"
            v-has="'dailyMaintenanceStandard:edit'"
          >编辑</a>
          <a-divider type="vertical" />
          <a-popconfirm
            v-if="record.versionStatus == '1'"
            title="确定删除吗?"
            @confirm="() => handleDelete(record.id)"
            v-has="'dailyMaintenanceStandard:delete'"
          >
            <a>删除</a>
          </a-popconfirm>
        </span>

      </a-table>
      <a-tabs
        type="card"
        defaultActiveKey="1"
      >
        <a-tab-pane
          tab='保养明细'
          key="1"
        >
          <div
            class="table-operator"
            style="margin:-16px"
          >
            <daily-maintenance-standard-detail :maintenanceStandardId='maintenanceStandardId' />
          </div>
        </a-tab-pane>
        <a-tab-pane
          tab='计划用料'
          key="2"
        >
          <div
            class="table-operator"
            style="margin:-16px"
          >
            <maintenance-standard-planning-material :maintenanceStandardId='maintenanceStandardId' />
          </div>
        </a-tab-pane>
        <a-tab-pane
          tab='危险防控'
          key="3"
        >
          <div
            class="table-operator"
            style="margin:-16px"
          >
            <maintenance-standard-safety-requirement :maintenanceStandardId='maintenanceStandardId' />
          </div>
        </a-tab-pane>
        <a-tab-pane
          tab='作业指导书'
          key="4"
        >
          <div
            class="table-operator"
            style="margin:-16px"
          >
            <maintenance-standard-work-instruction :maintenanceStandardId='maintenanceStandardId' />
          </div>
        </a-tab-pane>

      </a-tabs>
    </div>

    <daily-maintenance-standard-modal
      ref='modalForm'
      @ok='modalFormOk'
    ></daily-maintenance-standard-modal>
  </a-card>
</template>

<script>

import { JeecgListMixin } from '@/mixins/JeecgListMixin'

import { getAction, postAction, requestPut } from '@/api/manage'
import DailyMaintenanceStandardDetail from './modules/dailyMaintenanceStandard/DailyMaintenanceStandardDetail'
import MaintenanceStandardPlanningMaterial from '@/views/eam/modules/dailyMaintenanceStandard/MaintenanceStandardPlanningMaterial'
import MaintenanceStandardSafetyRequirement from '@/views/eam/modules/dailyMaintenanceStandard/MaintenanceStandardSafetyRequirement'
import DailyMaintenanceStandardModal from './modules/dailyMaintenanceStandard/DailyMaintenanceStandardModal'
import MaintenanceStandardWorkInstruction from '@/views/eam/modules/dailyMaintenanceStandard/MaintenanceStandardWorkInstruction'
import '@/assets/less/TableExpand.less'

export default {
  name: 'DailyMaintenanceStandardList',
  mixins: [JeecgListMixin],
  components: {
    DailyMaintenanceStandardDetail,
    DailyMaintenanceStandardModal,
    MaintenanceStandardPlanningMaterial,
    MaintenanceStandardSafetyRequirement,
    MaintenanceStandardWorkInstruction
  },
  data() {
    return {
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: 'center',
          customRender: function (t, r, index) {
            return parseInt(index) + 1
          }
        },
        {
          title: '版本',
          align: 'center',
          dataIndex: 'version',
        },
        {
          title: '版本状态',
          align: 'center',
          dataIndex: 'versionStatusName',
        },
        {
          title: '标准编码',
          align: 'center',
          dataIndex: 'num',
        },

        {
          title: '设备编码',
          align: 'center',
          dataIndex: 'equipmentNum',
        },
        {
          title: '设备名称',
          align: 'center',
          dataIndex: 'equipmentName',
        },
        {
          title: '设备型号',
          align: 'center',
          dataIndex: 'equipmentModel',
        },
        {
          title: '对象部门',
          align: 'center',
          dataIndex: 'useDepartName',
        },
        {
          title: '派工方式',
          align: 'center',
          dataIndex: 'assignModeName',
        },
        {
          title: '责任班组',
          align: 'center',
          dataIndex: 'teamName',
        },
        {
          title: '特种设备',
          align: 'center',
          dataIndex: 'specificEquipment',
        },
        {
          title: '创建人',
          align: 'center',
          dataIndex: 'createBy',
        },
        {
          title: '创建日期',
          align: 'center',
          dataIndex: 'createTime',
        },
        // {
        //   title: '更新人',
        //   align: 'center',
        //   dataIndex: 'updateBy',
        // },
        // {
        //   title: '更新日期',
        //   align: 'center',
        //   dataIndex: 'updateTime',
        // },
        {
          title: '操作',
          dataIndex: 'action',
          align: 'center',
          fixed: 'right',
          scopedSlots: { customRender: 'action' },
          width: 200,
        }
      ],
      url: {
        list: '/eam/maintenanceStandard/getMaintenanceStandardList',
        delete: '/eam/maintenanceStandard/delete',
        deleteBatch: '/eam/maintenanceStandard/deleteBatch',
        versionTakeEffect: "/eam/maintenanceStandard/versionTakeEffect",
      },
      /* 分页参数 */
      ipagination: {
        current: 1,
        pageSize: 5,
        pageSizeOptions: ['5', '10', '50'],
        showTotal: (total, range) => {
          return range[0] + '-' + range[1] + ' 共' + total + '条'
        },
        showQuickJumper: true,
        showSizeChanger: true,
        total: 0
      },
      maintenanceStandardId: '-1',
      queryParam: { type: 'daily' }
    }
  },
  watch: {
    selectionRows() {
      this.$bus.$emit('dailyMaintenanceStandardSelectionRows', this.selectionRows);
    },
  },
  methods: {
    clickThenSelect(record) {
      return {
        on: {
          click: () => {
            this.onSelectChange(record.id.split(','), [record])
          }
        }
      }
    },
    onClearSelected() {
      this.selectedRowKeys = []
      this.selectionRows = []
      this.maintenanceStandardId = '-1'
    },
    onSelectChange(selectedRowKeys, selectionRows) {
      if (selectedRowKeys.length == 1) {
        this.maintenanceStandardId = selectionRows[0]['id']
      } else {
        this.maintenanceStandardId = '-1'
      }
      this.selectedRowKeys = selectedRowKeys
      this.selectionRows = selectionRows
    },

    onChange(e) {
      this.queryParam.versionStatus = e.target.value;
      this.loadData();
    },

    loadData(arg) {
      if (!this.url.list) {
        this.$message.error('请设置url.list属性!')
        return
      }
      //加载数据 若传入参数1则加载第一页的内容
      if (arg === 1) {
        this.ipagination.current = 1
      }
      this.onClearSelected()
      var params = this.getQueryParams()//查询条件
      this.loading = true
      getAction(this.url.list, params).then((res) => {
        if (res.success) {
          this.dataSource = res.result.records
          this.ipagination.total = res.result.total
        }
        if (res.code === 510) {
          this.$message.warning(res.message)
        }
        this.loading = false
      })
    },

    handleEdit: function (record) {
      this.$refs.modalForm.edit(record)
      this.$refs.modalForm.title = '编辑'
      this.$refs.modalForm.disableSubmit = false
      this.$refs.modalForm.isRevise = false;
    },
    handleAdd: function () {
      this.$refs.modalForm.add()
      this.$refs.modalForm.title = '新增'
      this.$refs.modalForm.disableSubmit = false
      this.$refs.modalForm.isRevise = false;
    },

    //升版
    handleRevise: function (record) {
      this.$refs.modalForm.edit(record);
      this.$refs.modalForm.title = "保养标准版本升级";
      this.$refs.modalForm.disableSubmit = false;
      this.$refs.modalForm.isRevise = true;
    },

    //生效
    handleTakeEffect(record) {
      const that = this;
      that.confirmLoading = true;
      this.$confirm({
        title: '日常保养标准版本生效！',
        content: '提示：版本生效后上一版本将自动失效，请谨慎操作！',
        okText: '确认',
        cancelText: '取消',
        onOk() {
          requestPut(that.url.versionTakeEffect, { id: record.id, num: record.num, versionStatus: '2' }).then((res) => {
            if (res.success) {
              that.$message.success("版本生效成功！")
              that.loadData(1)
            } else {
              that.$message.warning("版本生效失败！")
            }
          }).finally(() => {
            that.confirmLoading = false;
          })
        },
      })
    },

    searchReset() {
      this.maintenanceStandardId = '-1'
      this.queryParam = { type: 'daily' }
      this.loadData(1);
    },
  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
.table-operator .ant-btn {
  margin: 10px 8px 8px 10px;
}
</style>